@@ -17,7 +17,7 @@
 # Operation failed.
 FAILEDOPERATION = 'FailedOperation'
 
-# 
+# Operation failed.
 FAILEDOPERATION_CHECKIFSUPPORTPODSTRETCH = 'FailedOperation.CheckIfSupportPodStretch'
 
 # Duplicate order. Please check the EMR console.
@@ -104,6 +104,9 @@ INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 # The number of master nodes is invalid.
 INVALIDPARAMETER_INCORRECTMASTERCOUNT = 'InvalidParameter.IncorrectMasterCount'
 
+# Invalid `AllNodeResourceSpec`.
+INVALIDPARAMETER_INVALIDALLNODERESOURCESPEC = 'InvalidParameter.InvalidAllNodeResourceSpec'
+
 # Invalid `AppId`.
 INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'
 
@@ -137,6 +140,9 @@ INVALIDPARAMETER_INVALIDCOUNTNUM = 'InvalidParameter.InvalidCountNum'
 # Error message: Invalid PodParameter.
 INVALIDPARAMETER_INVALIDCUSTOMIZEDPODPARAM = 'InvalidParameter.InvalidCustomizedPodParam'
 
+# Conflict between`DependService` and `EnableKerberos`.
+INVALIDPARAMETER_INVALIDDEPENDSERVICEANDENABLEKERBEROSCONFLICT = 'InvalidParameter.InvalidDependServiceAndEnableKerberosConflict'
+
 # Invalid disk size.
 INVALIDPARAMETER_INVALIDDISKSIZE = 'InvalidParameter.InvalidDiskSize'
 
@@ -146,6 +152,9 @@ INVALIDPARAMETER_INVALIDEKSINSTANCE = 'InvalidParameter.InvalidEksInstance'
 # Invalid `CustomConfig`.
 INVALIDPARAMETER_INVALIDEXTENDFIELD = 'InvalidParameter.InvalidExtendField'
 
+# Invalid instance billing mode.
+INVALIDPARAMETER_INVALIDINSTANCECHARGETYPE = 'InvalidParameter.InvalidInstanceChargeType'
+
 # Invalid cluster name.
 INVALIDPARAMETER_INVALIDINSTANCENAME = 'InvalidParameter.InvalidInstanceName'
 
@@ -182,15 +191,24 @@ INVALIDPARAMETER_INVALIDPREEXECUTEDFILE = 'InvalidParameter.InvalidPreExecutedFi
 # Invalid product ID.
 INVALIDPARAMETER_INVALIDPRODUCTID = 'InvalidParameter.InvalidProductId'
 
+# Invalid product version.
+INVALIDPARAMETER_INVALIDPRODUCTVERSION = 'InvalidParameter.InvalidProductVersion'
+
 # Invalid project ID.
 INVALIDPARAMETER_INVALIDPROJECTID = 'InvalidParameter.InvalidProjectId'
 
+# Invalid auto-renewal identifier.
+INVALIDPARAMETER_INVALIDRENEWFLAG = 'InvalidParameter.InvalidRenewFlag'
+
 # Invalid resource ID.
 INVALIDPARAMETER_INVALIDRESOURCEIDS = 'InvalidParameter.InvalidResourceIds'
 
 # Invalid resource specification.
 INVALIDPARAMETER_INVALIDRESOURCESPEC = 'InvalidParameter.InvalidResourceSpec'
 
+# Invalid bootstrap script execution parameter.
+INVALIDPARAMETER_INVALIDSCRIPTBOOTSTRAPACTIONCONFIG = 'InvalidParameter.InvalidScriptBootstrapActionConfig'
+
 # This EMR version does not support the security mode.
 INVALIDPARAMETER_INVALIDSECURITYSUPPORT = 'InvalidParameter.InvalidSecuritySupport'
 
@@ -245,6 +263,9 @@ INVALIDPARAMETER_INVALIDVPCID = 'InvalidParameter.InvalidVpcId'
 # Invalid AZ.
 INVALIDPARAMETER_INVALIDZONE = 'InvalidParameter.InvalidZone'
 
+# Invalid identifier for Kerberos support.
+INVALIDPARAMETER_KERBEROSSUPPORT = 'InvalidParameter.KerberosSupport'
+
 # Invalid parameter. Necessary components are missing.
 INVALIDPARAMETER_NOTCONTAINMUSTSELECTSOFTWARE = 'InvalidParameter.NotContainMustSelectSoftware'
 
